@@ -238,6 +238,28 @@ not been filled in with new information when the signal returns.
     \note You cannot use Qt::QueuedConnection when connecting to this signal, or calling
     QWebSocket::ignoreSslErrors() will have no effect.
 */
+/*!
+    \fn void QWebSocket::preSharedKeyAuthenticationRequired(QSslPreSharedKeyAuthenticator *authenticator)
+    \since 5.8
+
+    This signal is emitted if the SSL/TLS handshake negotiates a PSK
+    ciphersuite, and therefore a PSK authentication is then required.
+
+    When using PSK, the client must send to the server a valid identity and a
+    valid pre shared key, in order for the SSL handshake to continue.
+    Applications can provide this information in a slot connected to this
+    signal, by filling in the passed \a authenticator object according to their
+    needs.
+
+    \note Ignoring this signal, or failing to provide the required credentials,
+    will cause the handshake to fail, and therefore the connection to be aborted.
+
+    \note The \a authenticator object is owned by the websocket and must not be
+    deleted by the application.
+
+    \sa QSslPreSharedKeyAuthenticator
+    \sa QSslSocket::preSharedKeyAuthenticationRequired()
+*/
 /*!
     \fn void QWebSocket::pong(quint64 elapsedTime, const QByteArray &payload)
 
